@@ -7,7 +7,7 @@ RDF::Query::Algebra - Base class for Algebra expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra version 2.905.
+This document describes RDF::Query::Algebra version 2.906.
 
 =head1 METHODS
 
@@ -19,7 +19,7 @@ package RDF::Query::Algebra;
 
 our (@ISA, @EXPORT_OK);
 BEGIN {
-	our $VERSION	= '2.905';
+	our $VERSION	= '2.906';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -178,7 +178,7 @@ sub _check_duplicate_blanks {
 	return @data;
 }
 
-=item C<< qualify_uris ( \%namespaces, $base ) >>
+=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -189,11 +189,11 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base	= shift;
+	my $base_uri	= shift;
 	my @args;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@args, $arg->qualify_uris( $ns, $base ));
+			push(@args, $arg->qualify_uris( $ns, $base_uri ));
 		} elsif (blessed($arg) and $arg->isa('RDF::Query::Node::Resource')) {
 			my $uri	= $arg->uri_value;
 			if (ref($uri)) {
