@@ -7,7 +7,7 @@ RDF::Query::ExecutionContext - Query execution context
 
 =head1 VERSION
 
-This document describes RDF::Query::ExecutionContext version 2.905.
+This document describes RDF::Query::ExecutionContext version 2.906.
 
 =head1 METHODS
 
@@ -24,7 +24,7 @@ use warnings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -96,6 +96,15 @@ sub query {
 	return $self->_get_value( 'query', @_ );
 }
 
+=item C<< options >>
+
+=cut
+
+sub options {
+	my $self	= shift;
+	return $self->_get_value( 'options', @_ );
+}
+
 =item C<< bound >>
 
 =cut
@@ -105,13 +114,25 @@ sub bound {
 	return $self->_get_value( 'bound', @_ ) || {};
 }
 
+=item C<< base_uri >>
+
+=cut
+
+sub base_uri {
+	my $self	= shift;
+	return $self->_get_value( 'base_uri', @_ ) || {};
+}
+
 =item C<< base >>
 
+Deprecated, use base_uri.
+
 =cut
 
 sub base {
 	my $self	= shift;
-	return $self->_get_value( 'base', @_ ) || {};
+	warn "The RDF::QueryExecutionContext base method is deprecated in favor of base_uri";
+	return $self->base_uri(@_);
 }
 
 =item C<< ns >>
