@@ -7,7 +7,7 @@ RDF::Query::Expression - Class for Expr expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression version 2.905.
+This document describes RDF::Query::Expression version 2.906.
 
 =cut
 
@@ -26,7 +26,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -101,6 +101,27 @@ sub sse {
 	);
 }
 
+=item C<< explain >>
+
+Returns a string serialization of the expression appropriate for display on the
+command line. This method is primarily used by the C<< explain >> method of
+the subclasses of RDF::Query::Plan.
+
+=cut
+
+sub explain {
+	my $self	= shift;
+	my $s		= shift;
+	my $count	= shift;
+	my $indent	= $s x $count;
+	my $type	= $self->op;
+	my $string	= "${indent}${type}\n";
+	foreach my $p ($self->operands) {
+		$string	.= $p->explain( $s, $count+1 );
+	}
+	return $string;
+}
+
 =item C<< type >>
 
 Returns the type of this algebra expression.
