@@ -7,7 +7,7 @@ RDF::Query::Expression::Function - Class for Function expressions
 
 =head1 VERSION
 
-This document describes RDF::Query::Expression::Function version 2.905.
+This document describes RDF::Query::Expression::Function version 2.906.
 
 =cut
 
@@ -27,7 +27,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -172,7 +172,7 @@ sub type {
 	return 'FUNCTION';
 }
 
-=item C<< qualify_uris ( \%namespaces, $base ) >>
+=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -183,11 +183,11 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base	= shift;
+	my $base_uri	= shift;
 	my @args;
 	foreach my $arg ($self->construct_args) {
 		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@args, $arg->qualify_uris( $ns, $base ));
+			push(@args, $arg->qualify_uris( $ns, $base_uri ));
 		} elsif (blessed($arg) and $arg->isa('RDF::Query::Node::Resource')) {
 			my $uri	= $arg->uri;
 			if (ref($uri)) {
@@ -195,7 +195,7 @@ sub qualify_uris {
 				unless (exists($ns->{ $n })) {
 					throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 				}
-				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base );
+				my $resolved	= RDF::Query::Node::Resource->new( join('', $ns->{ $n }, $l), $base_uri );
 				push(@args, $resolved);
 			} else {
 				push(@args, $arg);
@@ -250,7 +250,7 @@ sub evaluate {
 		my $expr	= shift(@args);
 		my $index	= 1;
 		try {
-			my $exprval	= $query->var_or_expr_value( $bound, $expr );
+			my $exprval	= $query->var_or_expr_value( $bound, $expr, $context );
 			my $func	= RDF::Query::Expression::Function->new( $ebv, $exprval );
 			my $value	= $func->evaluate( $query, {}, $context );
 			my $bool	= ($value->literal_value eq 'true') ? 1 : 0;
@@ -259,7 +259,7 @@ sub evaluate {
 			}
 		} catch RDF::Query::Error::TypeError with {};
 		my $expr2	= $args[$index];
-		return $query->var_or_expr_value( $bound, $expr2 );
+		return $query->var_or_expr_value( $bound, $expr2, $context );
 	} elsif ($uriv eq 'sparql:exists') {
 		my $func	= $query->get_function($uri);
 		my ($ggp)	= $self->arguments;
