@@ -7,7 +7,7 @@ RDF::Query::Parser::SPARQL11 - SPARQL 1.1 Parser.
 
 =head1 VERSION
 
-This document describes RDF::Query::Parser::SPARQL11 version 2.905.
+This document describes RDF::Query::Parser::SPARQL11 version 2.906.
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ use Scalar::Util qw(blessed looks_like_number reftype);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -326,6 +326,13 @@ sub _RW_Query {
 			$self->_MoveUpdate();
 		} elsif ($self->_test(qr/ADD/i)) {
 			$self->_AddUpdate();
+		} elsif ($self->_test(qr/;/)) {
+			$self->_eat(qr/;/) ;
+			$self->__consume_ws_opt;
+			next if ($self->_Query_test);
+			last;
+		} elsif ($self->{tokens} eq '') {
+			last;
 		} else {
 			my $l		= Log::Log4perl->get_logger("rdf.query");
 			if ($l->is_debug) {
@@ -333,6 +340,7 @@ sub _RW_Query {
 			}
 			throw RDF::Query::Error::ParseError -text => 'Syntax error: Expected query type';
 		}
+		
 		last if ($read_query);
 		$self->__consume_ws_opt;
 		if ($self->_test(qr/;/)) {
@@ -353,7 +361,7 @@ sub _RW_Query {
 		throw RDF::Query::Error::ParseError -text => "Syntax error: Remaining input after query: $remaining";
 	}
 	
-	if ($count > 1) {
+	if ($count == 0 or $count > 1) {
 		my @patterns	= splice(@{ $self->{build}{triples} });
 		$self->{build}{triples}	= [ RDF::Query::Algebra::Sequence->new( @patterns ) ];
 	}
@@ -437,6 +445,7 @@ sub _DeleteDataUpdate {
 	$self->_eat('{');
 	$self->__consume_ws_opt;
 	local($self->{__data_pattern})	= 1;
+	local($self->{__no_bnodes})		= "DELETE DATA block";
 	$self->_ModifyTemplate();
 	$self->__consume_ws_opt;
 	my $data	= $self->_remove_pattern;
@@ -521,11 +530,14 @@ sub _DeleteUpdate {
 		}
 		$delete_where	= 1;
 	} else {
-		$self->_eat('{');
-		$self->__consume_ws_opt;
-		$self->_ModifyTemplate( $graph );
-		$self->__consume_ws_opt;
-		$self->_eat('}');
+		{
+			local($self->{__no_bnodes})		= "DELETE block";
+			$self->_eat('{');
+			$self->__consume_ws_opt;
+			$self->_ModifyTemplate( $graph );
+			$self->__consume_ws_opt;
+			$self->_eat('}');
+		}
 		$delete_data	= $self->_remove_pattern;
 		
 		$self->__consume_ws_opt;
@@ -565,12 +577,16 @@ sub _DeleteUpdate {
 	$self->__consume_ws_opt;
 	if ($graph) {
 #  		local($self->{named_graph})	= $graph;
+		$self->{__no_bnodes}	= "DELETE WHERE block" if ($delete_where);
 		$self->_GroupGraphPattern;
+		delete $self->{__no_bnodes};
 		my $ggp	= $self->_remove_pattern;
 		$ggp	= RDF::Query::Algebra::NamedGraph->new( $graph, $ggp );
 		$self->_add_patterns( $ggp );
 	} else {
+		$self->{__no_bnodes}	= "DELETE WHERE block" if ($delete_where);
 		$self->_GroupGraphPattern;
+		delete $self->{__no_bnodes};
 	}
 
 	my $ggp	= $self->_remove_pattern;
@@ -998,6 +1014,7 @@ sub _ConstructQuery {
 		$self->_WhereClause;
 	}
 	
+	$self->__consume_ws_opt;
 	$self->_SolutionModifier();
 	
 	my $pattern		= $self->{build}{triples}[0];
@@ -1035,6 +1052,7 @@ sub _DescribeQuery {
 		$self->_WhereClause;
 	}
 	
+	$self->__consume_ws_opt;
 	$self->_SolutionModifier();
 	$self->{build}{method}		= 'DESCRIBE';
 }
@@ -1167,6 +1185,7 @@ sub _Binding {
 
 sub _BindingValue_test {
 	my $self	= shift;
+	return 1 if ($self->_IRIref_test);
 	return 1 if ($self->_test(qr/UNDEF|[<'".0-9]|(true|false)\b|_:|\([\n\r\t ]*\)/));
 	return 0;
 }
@@ -2121,7 +2140,8 @@ sub _VerbSimple {
 sub _VerbPath_test {
 	my $self	= shift;
 	return 1 if ($self->_IRIref_test);
-	return 1 if ($self->_test(qr/\^|[(a!]/));
+	return 1 if ($self->_test(qr/\^|[|(a!]/));
+	return 0;
 }
 
 sub _VerbPath {
@@ -2146,7 +2166,8 @@ sub _PathAlternative {
 		my ($lhs)	= splice(@{ $self->{stack} });
 		$self->_eat(qr/[|]/);
 		$self->__consume_ws_opt;
-		$self->_PathOneInPropertyClass;
+#		$self->_PathOneInPropertyClass;
+		$self->_PathSequence;
 		$self->__consume_ws_opt;
 		my ($rhs)	= splice(@{ $self->{stack} });
 		$self->_add_stack( ['PATH', '|', $lhs, $rhs] );
@@ -2227,8 +2248,14 @@ sub _PathMod {
 	} else {
 		$self->_eat(qr/{/);
 		$self->__consume_ws_opt;
-		my $value	= $self->_eat( $r_INTEGER );
-		$self->__consume_ws_opt;
+		my $value	= 0;
+		if ($self->_test(qr/}/)) {
+			throw RDF::Query::Error::ParseError -text => "Syntax error: Empty Path Modifier";
+		}
+		if ($self->_test($r_INTEGER)) {
+			$value	= $self->_eat( $r_INTEGER );
+			$self->__consume_ws_opt;
+		}
 		if ($self->_test(qr/,/)) {
 			$self->_eat(qr/,/);
 			$self->__consume_ws_opt;
@@ -2353,6 +2380,9 @@ sub _TriplesNode {
 # [39] BlankNodePropertyList ::= '[' PropertyListNotEmpty ']'
 sub _BlankNodePropertyList {
 	my $self	= shift;
+	if (my $where = $self->{__no_bnodes}) {
+		throw RDF::Query::Error::ParseError -text => "Syntax error: Blank nodes not allowed in $where";
+	}
 	$self->_eat('[');
 	$self->__consume_ws_opt;
 #	$self->_PropertyListNotEmpty;
@@ -2432,6 +2462,7 @@ sub _GraphNode {
 sub _VarOrTerm_test {
 	my $self	= shift;
 	return 1 if ($self->_test(qr/[\$?]/));
+	return 1 if ($self->_IRIref_test);
 	return 1 if ($self->_test(qr/[<'".0-9]|(true|false)\b|_:|\([\n\r\t ]*\)/));
 	return 0;
 }
@@ -3053,6 +3084,9 @@ sub _PrefixedName {
 # [69] BlankNode ::= BLANK_NODE_LABEL | ANON
 sub _BlankNode {
 	my $self	= shift;
+	if (my $where = $self->{__no_bnodes}) {
+		throw RDF::Query::Error::ParseError -text => "Syntax error: Blank nodes not allowed in $where";
+	}
 	if ($self->_test( $r_BLANK_NODE_LABEL )) {
 		my $label	= $self->_eat( $r_BLANK_NODE_LABEL );
 		my $id		= substr($label,2);
@@ -3255,6 +3289,7 @@ sub _syntax_error {
 	my $near	= "'" . substr($self->{tokens}, 0, 20) . "...'";
 	$near		=~ s/[\r\n ]+/ /g;
 	if ($thing) {
+# 		Carp::cluck Dumper($self->{tokens});	# XXX
 		throw RDF::Query::Error::ParseError -text => "Syntax error: $thing in $expect near $near";
 	} else {
 		throw RDF::Query::Error::ParseError -text => "Syntax error: Expected $expect near $near";
