@@ -7,7 +7,7 @@ RDF::Query::Plan::Join - Join query plan base class.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Join version 2.905.
+This document describes RDF::Query::Plan::Join version 2.906.
 
 =head1 METHODS
 
@@ -31,7 +31,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -138,8 +138,17 @@ Returns the class names of all available join algorithms.
 
 sub join_classes {
 	my $class	= shift;
+	my $config	= shift || {};
 	our %JOIN_CLASSES;
-	return reverse sort keys %JOIN_CLASSES;
+	my @classes	= reverse sort keys %JOIN_CLASSES;
+	my @ok	= grep { 
+		my $name	= lc($_);
+		$name	=~ s/::/./g;
+		(exists $config->{ $name } and not($config->{ $name }))
+			? 0
+			: 1
+	} @classes;
+	return @ok;
 }
 
 =item C<< distinct >>
