@@ -7,7 +7,7 @@ RDF::Query::Plan::Sort - Executable query plan for Sorts.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Sort version 2.905.
+This document describes RDF::Query::Plan::Sort version 2.906.
 
 =head1 METHODS
 
@@ -28,7 +28,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -63,14 +63,24 @@ sub execute ($) {
 	my $plan	= $self->[1];
 	$plan->execute( $context );
 	
+	my $l		= Log::Log4perl->get_logger("rdf.query.plan.sort");
+	$l->trace("executing sort");
 	if ($plan->state == $self->OPEN) {
 		my $exprs	= $self->[2];
 		my @rows	= $plan->get_all;
+		if ($l->is_trace) {
+			$l->trace("sorting result list:");
+			$l->trace("- $_") foreach (@rows);
+		}
 		my $query	= $context->query;
 		
 		use sort 'stable';
-		@rows		= sort { _cmp_rows( $context, $exprs, $a, $b ) } @rows;
-		$self->[0]{rows}	= \@rows;
+		my @sorted	= sort { _cmp_rows( $context, $exprs, $a, $b ) } @rows;
+		if ($l->is_trace) {
+			$l->trace("sorted list:");
+			$l->trace("- $_") foreach (@sorted);
+		}
+		$self->[0]{rows}	= \@sorted;
 		$self->state( $self->OPEN );
 	} else {
 		warn "could not execute plan in distinct";
@@ -110,6 +120,7 @@ sub _cmp_rows {
 	my $a		= shift;
 	my $b		= shift;
 	
+	my $l		= Log::Log4perl->get_logger("rdf.query.plan.sort");
 	my $query	= $context->query || 'RDF::Query';
 	my $bridge	= $context->model;
 	
@@ -117,18 +128,21 @@ sub _cmp_rows {
 	no warnings 'uninitialized';
 	foreach my $data (@$exprs) {
 		my ($expr, $rev)	= @$data;
-		my $a_val	= $query->var_or_expr_value( $a, $expr );
-		my $b_val	= $query->var_or_expr_value( $b, $expr );
+		my $a_val	= $query->var_or_expr_value( $a, $expr, $context );
+		my $b_val	= $query->var_or_expr_value( $b, $expr, $context );
 		local($RDF::Query::Node::Literal::LAZY_COMPARISONS)	= 1;
+		$l->trace("comparing $a_val <=> $b_val");
 		my $cmp		= $a_val <=> $b_val;
 		if ($cmp != 0) {
 			if ($rev) {
 				$cmp	*= -1;
 			}
+			$l->trace("==> $cmp");
 			return $cmp;
 		} else {
 		}
 	}
+	$l->trace("==> 0");
 	return 0;
 }
 
@@ -217,6 +231,30 @@ sub graph {
 	return "$self";
 }
 
+=item C<< explain >>
+
+Returns a string serialization of the plan appropriate for display on the
+command line.
+
+=cut
+
+sub explain {
+	my $self	= shift;
+	my $s		= shift;
+	my $count	= shift;
+	my $indent	= $s x $count;
+	my $type	= $self->plan_node_name;
+	my $string	= "${indent}${type}\n";
+	$string		.= "${indent}${s}sory by:\n";
+	my $exprs	= $self->[2];
+	foreach my $e (@$exprs) {
+		my $dir		= ($e->[1] == 0 ? 'asc  ' : 'desc ');
+		$string		.= "${indent}${s}${s}${dir}" . $e->[0] . "\n";
+	}
+	$string		.= $self->pattern->explain( $s, $count+1 );
+	return $string;
+}
+
 
 1;
 
