@@ -7,7 +7,7 @@ RDF::Query::Plan::Update - Executable query plan for DELETE/INSERT operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Update version 2.905.
+This document describes RDF::Query::Plan::Update version 2.906.
 
 =head1 METHODS
 
@@ -36,7 +36,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -100,11 +100,23 @@ sub execute ($) {
 					for my $i (0 .. $#nodes) {
 						if ($nodes[$i]->isa('RDF::Trine::Node::Variable')) {
 							my $name	= $nodes[$i]->name;
-							$nodes[$i]	= $row->{ $name };
+							if ($method eq 'remove_statements') {
+								if (exists($row->{ $name })) {
+									$nodes[$i]	= $row->{ $name };
+								} else {
+									next TRIPLE;
+								}
+							} else {
+								$nodes[$i]	= $row->{ $name };
+							}
 						} elsif ($nodes[$i]->isa('RDF::Trine::Node::Blank')) {
 							my $id	= $nodes[$i]->blank_identifier;
 							unless (exists($self->[0]{blank_map}{ $id })) {
-								$self->[0]{blank_map}{ $id }	= RDF::Trine::Node::Blank->new();
+								if ($method eq 'remove_statements') {
+									$self->[0]{blank_map}{ $id }	= RDF::Query::Node::Variable->new();
+								} else {
+									$self->[0]{blank_map}{ $id }	= RDF::Query::Node::Blank->new();
+								}
 							}
 							$nodes[$i]	= $self->[0]{blank_map}{ $id };
 						}
@@ -273,6 +285,43 @@ sub plan_node_data {
 	return ($self->delete_template, $self->insert_template, $self->pattern);
 }
 
+=item C<< explain >>
+
+Returns a string serialization of the algebra appropriate for display on the
+command line.
+
+=cut
+
+sub explain {
+	my $self	= shift;
+	my $s		= shift;
+	my $count	= shift;
+	my $indent	= $s x $count;
+	my $type	= $self->plan_node_name;
+	my $string	= "${indent}$type\n";
+	
+	if (my $d = $self->delete_template) {
+		$string	.= "${indent}${s}delete:\n";
+		$string	.= $d->explain( $s, $count+2 );
+	}
+
+	if (my $i = $self->insert_template) {
+		$string	.= "${indent}${s}insert:\n";
+		$string	.= $i->explain( $s, $count+2 );
+	}
+
+	if (my $p = $self->pattern) {
+		if ($p->isa('RDF::Query::Plan::Constant') and $p->is_unit) {
+			
+		} else {
+			$string	.= "${indent}${s}where:\n";
+			$string	.= $p->explain( $s, $count+2 );
+		}
+	}
+	
+	return $string;
+}
+
 =item C<< graph ( $g ) >>
 
 =cut
