@@ -7,7 +7,7 @@ RDF::Query::VariableBindings - Variable bindings
 
 =head1 VERSION
 
-This document describes RDF::Query::VariableBindings version 2.905.
+This document describes RDF::Query::VariableBindings version 2.906.
 
 =head1 METHODS
 
@@ -32,7 +32,7 @@ use Scalar::Util qw(blessed refaddr);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.905';
+	$VERSION	= '2.906';
 }
 
 ######################################################################
@@ -43,7 +43,7 @@ BEGIN {
 
 sub new {
 	my $class		= shift;
-	my $bindings	= shift;
+	my $bindings	= shift || {};
 	my $data		= { %$bindings };
 	foreach my $k (keys %$data) {
 		my $node	= $data->{$k};
@@ -69,6 +69,27 @@ sub sse {
 	return sprintf('(row %s)', CORE::join(' ', map { '[' . CORE::join(' ', '?' . $_, ($self->{$_}) ? $self->{$_}->as_string : ()) . ']' } (@keys)));
 }
 
+=item C<< explain >>
+
+Returns a string serialization of the variable bindings appropriate for display
+on the command line.
+
+=cut
+
+sub explain {
+	my $self	= shift;
+	my $s		= shift;
+	my $count	= shift;
+	my $indent	= $s x $count;
+	my $string	= "${indent}Variable Bindings\n";
+
+	my @keys	= sort keys %$self;
+	foreach my $k (@keys) {
+		$string	.= "${indent}${s}$k: " . $self->{$k}->as_string . "\n";
+	}
+	return $string;
+}
+
 1;
 
 __END__
